Learn R Programming

multiview (version 0.8)

reshape_x_to_xlist: Return a new list of x matrices of same shapes as those in x_list

Description

Return a new list of x matrices of same shapes as those in x_list

Usage

reshape_x_to_xlist(x, x_list)

Arguments

x

the column-binded entries of x_list

x_list

a list of x matrices with same number of rows nobs