Learn R Programming

multiview (version 0.8)

to_nvar_index: Translate from column indices in list of x matrices to indices in 1:nvars. No sanity checks for efficiency

Description

Translate from column indices in list of x matrices to indices in 1:nvars. No sanity checks for efficiency

Usage

to_nvar_index(x_list, index_list)

Value

a vector of indices between 1 and nvars = sum of ncol(x)

for x in x_list

Arguments

x_list

a list of x matrices with same number of rows nobs

index_list

a list of column indices for each matrix, including possibly column indices of length 0