Learn R Programming

multiview (version 0.8)

to_xlist_index: Translate indices in 1:nvars to column indices in list of x matrices. No sanity checks

Description

Translate indices in 1:nvars to column indices in list of x matrices. No sanity checks

Usage

to_xlist_index(x_list, index)

Value

a conformed list of column indices for each matrix, including possibly column indices of length 0

Arguments

x_list

a list of x matrices with same number of rows nobs

index

vector of indices between 1 and nvars = sum of ncol(x) for x in x_list