1:nvars to column indices in list of x
matrices. No sanity checksTranslate indices in 1:nvars to column indices in list of x
matrices. No sanity checks
to_xlist_index(x_list, index)a conformed list of column indices for each matrix, including possibly column indices of length 0
a list of x matrices with same number of rows
nobs
vector of indices between 1 and nvars = sum of
ncol(x) for x in x_list